"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
class DisplayIdleWatcher {
    constructor(displayService, alarmService) {
        this.timerInterval = 2000;
        this.displayService = displayService;
        this.alarmService = alarmService;
    }
    get isWatching() {
        return this.timerReference === null;
    }
    startWatching(accesskey) {
        if (this.timerReference !== null)
            clearInterval(this.timerReference);
        this.timerReference = setInterval(() => __awaiter(this, void 0, void 0, function* () {
            try {
                const activeAlarm = yield this.alarmService.getActiveAlarm(accesskey);
                if (activeAlarm === null && this.lastAlarmId !== null) {
                    this.lastAlarmId = null;
                    this.displayService.turnOff();
                    return;
                }
                if (activeAlarm !== null && (this.lastAlarmId === null || activeAlarm.id !== this.lastAlarmId)) {
                    this.displayService.turnOn();
                    this.lastAlarmId = activeAlarm.id;
                    return;
                }
            }
            catch (error) {
                console.error(error);
            }
        }), this.timerInterval);
    }
    stopWatching() {
        if (this.timerReference === null)
            return;
        clearInterval(this.timerReference);
        this.timerReference = null;
        this.displayService.turnOn();
    }
}
exports.default = DisplayIdleWatcher;
//# sourceMappingURL=DisplayIdleWatcher.js.map