"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const electron_1 = require("electron");
const database_1 = require("../infrastructure/database");
const api_1 = require("../application/api");
exports.default = () => {
    const authenticationService = api_1.APIFactory.getAuthenticationService();
    const database = database_1.DatabaseFactory.getDatabase();
    document.getElementById('submit').addEventListener('click', () => __awaiter(this, void 0, void 0, function* () {
        const usernameEl = document.getElementById('username');
        const username = usernameEl.value;
        const passwordEl = document.getElementById('password');
        const password = passwordEl.value;
        const autologinEl = document.getElementById('autologin');
        const autologin = autologinEl.value;
        // Check for (all) empty fields
        let error = false;
        if (username === undefined || username === '') {
            usernameEl.classList.add('error');
            error = true;
        }
        else
            usernameEl.classList.remove('error');
        if (password === undefined || password === '') {
            passwordEl.classList.add('error');
            error = true;
        }
        else
            passwordEl.classList.remove('error');
        if (autologin === undefined || autologin === '') {
            autologinEl.classList.add('error');
            error = true;
        }
        else
            autologinEl.classList.remove('error');
        if (error)
            return;
        try {
            // Retrieve accesskey, start auto turn on/off and forward to monitor
            const accesskey = yield authenticationService.getAccesskey(username, password);
            // Persistently save accesskey
            yield database.setValueForKey({ accesskey, autologin }, 'tokens');
            // Show fullsize monitor from autologin token
            const BrowserWindow = electron_1.remote.BrowserWindow;
            const currentWindow = electron_1.remote.getCurrentWindow();
            const { width, height } = electron_1.screen.getPrimaryDisplay().workAreaSize;
            const monitorWindow = new BrowserWindow({
                width,
                height,
                webPreferences: {
                    nodeIntegration: false
                }
            });
            monitorWindow.loadURL('https://divera247.com/monitor/1.html?autologin=' + autologin);
            // Create background window which holds display process
            const backgroundTaskWindow = new BrowserWindow({ show: false });
            backgroundTaskWindow.loadFile('src/html/backgroundTask.html');
            // Show console and background window if in app is in debug mode
            const isInDebugMode = process.env.DEBUG === 'true' || process.env.DEBUG === '1';
            if (isInDebugMode) {
                backgroundTaskWindow.webContents.toggleDevTools();
                backgroundTaskWindow.show();
            }
            // Close login window
            currentWindow.close();
        }
        catch (error) {
            alert(error);
        }
    }));
};
//# sourceMappingURL=login.js.map